@@ -1,6 +1,6 @@
 package POEx::IRC::Backend::Listener;
 {
-  $POEx::IRC::Backend::Listener::VERSION = '0.024000';
+  $POEx::IRC::Backend::Listener::VERSION = '0.024001';
 }
 use strictures 1;
 use Moo;
@@ -48,11 +48,4 @@ Can be altered via B<set_idle>
 
 Jon Portnoy <avenj@cobaltirc.org>
 
-=begin Pod::Coverage
-
-  set_\w+
-
-=end Pod::Coverage
-
-
 =cut
