@@ -1,6 +1,6 @@
 package POEx::IRC::Backend::Role::Connector;
 {
-  $POEx::IRC::Backend::Role::Connector::VERSION = '0.024000';
+  $POEx::IRC::Backend::Role::Connector::VERSION = '0.024001';
 }
 use 5.10.1;
 use strictures 1;
@@ -10,6 +10,7 @@ use MooX::Types::MooseLike::Base ':all';
 
 use namespace::clean;
 
+with 'POEx::IRC::Backend::Role::HasWheel';
 
 has addr => (
   required => 1,
@@ -32,26 +33,6 @@ has ssl => (
   default => sub { 0 },
 );
 
-has wheel_id => (
-  lazy    => 1,
-  isa     => Defined,
-  is      => 'ro',
-  writer  => '_set_wheel_id',
-);
-
-has wheel => (
-  required  => 1,
-  isa       => InstanceOf['POE::Wheel'],
-  is        => 'ro',
-  clearer   => 'clear_wheel',
-  writer    => 'set_wheel',
-  predicate => 'has_wheel',
-  trigger   => sub {
-    my ($self, $wheel) = @_;
-    $self->_set_wheel_id( $wheel->ID )
-  },
-);
-
 1;
 
 =pod
@@ -71,6 +52,9 @@ This role is consumed by L<POEx::IRC::Backend::Connector> and
 L<POEx::IRC::Backend::Listener> objects; it defines some basic attributes
 shared by listening/connecting sockets.
 
+This role consumes L<POEx::IRC::Backend::Role::HasWheel> and adds the
+following attributes:
+
 =head2 addr
 
 The local address we are bound to.
@@ -79,9 +63,10 @@ The local address we are bound to.
 
 The local port we are listening on.
 
-=for Pod::Coverage set_port
+=head2 set_port
+
+Change the current port attribute.
 
-B<set_port> can be used to alter the current port attribute.
 This won't trigger any automatic L</wheel> changes (at this time), 
 but it is useful when creating a listener on port 0.
 
@@ -93,20 +78,6 @@ The Internet protocol version for this listener (4 or 6).
 
 Boolean value indicating whether connections should be SSLified.
 
-=head2 wheel
-
-The L<POE::Wheel::SocketFactory> instance for this listener.
-
-Can be cleared via B<clear_wheel>; use B<has_wheel> to determine if this
-listener's wheel has been cleared.
-
-Can be replaced via B<set_wheel> (although whether this is a good idea or not
-is debatable; better to spawn a new instance of your class)
-
-=head2 wheel_id
-
-The POE ID of the last known L</wheel>.
-
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
